var NAVTREEINDEX3 =
{
"group__API__Data__Interfaces.html#gaef6039a7976d3ee6c6916df28a08da1a":[10,9,19],
"group__API__Data__Interfaces.html#gaefbbb2e643662ee4d7c816d91e8e14df":[10,9,99],
"group__API__Data__Interfaces.html#gaf011a057a557a66271ce06e8109c11c4":[10,9,73],
"group__API__Data__Interfaces.html#gaf0937aae4bedeb03e9ebbec36cc1dad6":[10,9,102],
"group__API__Data__Interfaces.html#gaf0fa0d2dc99ab880ccfe12061770dad2":[10,9,38],
"group__API__Data__Interfaces.html#gaf1843d7f93510e6bf53da173eb9dd75e":[10,9,159],
"group__API__Data__Interfaces.html#gaf3bd64a64625f45859f596db3bb9b40a":[10,9,42],
"group__API__Data__Interfaces.html#gaf5938ea67a4a2c4f140ec527698bf850":[10,9,181],
"group__API__Data__Interfaces.html#gaf5ea640f2c977e3ae95a6be9b3be3bee":[10,9,127],
"group__API__Data__Interfaces.html#gaf972d52af628f82488eeea311eadb4f6":[10,9,191],
"group__API__Data__Interfaces.html#gafb92c2538dc629d823221c5dc16bd767":[10,9,190],
"group__API__Data__Interfaces.html#gafd439524218c70b6b4a784fb12824c28":[10,9,215],
"group__API__Data__Interfaces.html#gafd9d133c4d658b777d9800eba79765b3":[10,9,37],
"group__API__Data__Interfaces.html#ggaa2f2140147f15e7b9eec1443690e357ca1020cba73248160933d8f6c901293437":[10,9,107,5],
"group__API__Data__Interfaces.html#ggaa2f2140147f15e7b9eec1443690e357ca264b360136a55f91ae62c48faa02f376":[10,9,107,1],
"group__API__Data__Interfaces.html#ggaa2f2140147f15e7b9eec1443690e357ca40a80154bc81a5eb4eea06771010bba3":[10,9,107,6],
"group__API__Data__Interfaces.html#ggaa2f2140147f15e7b9eec1443690e357ca4c3642251b2ddf957338ef2729de7f5f":[10,9,107,3],
"group__API__Data__Interfaces.html#ggaa2f2140147f15e7b9eec1443690e357ca5a50ee28bfd93b68341e7644f3e810aa":[10,9,107,4],
"group__API__Data__Interfaces.html#ggaa2f2140147f15e7b9eec1443690e357ca65cfc4ac63a449dd5da3c40ae63bb949":[10,9,107,0],
"group__API__Data__Interfaces.html#ggaa2f2140147f15e7b9eec1443690e357ca7b3ec1ca579bfc82a35d282ed69b0300":[10,9,107,10],
"group__API__Data__Interfaces.html#ggaa2f2140147f15e7b9eec1443690e357ca80d5bec40d12c9b05e1331bab739e39f":[10,9,107,9],
"group__API__Data__Interfaces.html#ggaa2f2140147f15e7b9eec1443690e357caa0881ef4be5491fcfb7df81b9778a247":[10,9,107,12],
"group__API__Data__Interfaces.html#ggaa2f2140147f15e7b9eec1443690e357caa45ce766ad2fe7020e82e462390c7b38":[10,9,107,8],
"group__API__Data__Interfaces.html#ggaa2f2140147f15e7b9eec1443690e357cab24c1ea83c1e376895d316a0981bee0c":[10,9,107,7],
"group__API__Data__Interfaces.html#ggaa2f2140147f15e7b9eec1443690e357cac55e5bac53f8121d107f4bebf2d26155":[10,9,107,11],
"group__API__Data__Interfaces.html#ggaa2f2140147f15e7b9eec1443690e357cacb8ea4adb7ed650338bfe9e69d3e1bb2":[10,9,107,2],
"group__API__Data__Interfaces.html#structstarpu__bcsr__interface":[10,9,10],
"group__API__Data__Interfaces.html#structstarpu__block__interface":[10,9,4],
"group__API__Data__Interfaces.html#structstarpu__coo__interface":[10,9,3],
"group__API__Data__Interfaces.html#structstarpu__csr__interface":[10,9,9],
"group__API__Data__Interfaces.html#structstarpu__data__copy__methods":[10,9,0],
"group__API__Data__Interfaces.html#structstarpu__data__interface__ops":[10,9,1],
"group__API__Data__Interfaces.html#structstarpu__matrix__interface":[10,9,2],
"group__API__Data__Interfaces.html#structstarpu__multiformat__data__interface__ops":[10,9,11],
"group__API__Data__Interfaces.html#structstarpu__multiformat__interface":[10,9,12],
"group__API__Data__Interfaces.html#structstarpu__ndim__interface":[10,9,6],
"group__API__Data__Interfaces.html#structstarpu__tensor__interface":[10,9,5],
"group__API__Data__Interfaces.html#structstarpu__variable__interface":[10,9,8],
"group__API__Data__Interfaces.html#structstarpu__vector__interface":[10,9,7],
"group__API__Data__Management.html":[10,8],
"group__API__Data__Management.html#ga00223a2f0608eb7893e87119937931d3":[10,8,58],
"group__API__Data__Management.html#ga06b01fdf769f8f2eb222ecde42afbc81":[10,8,17],
"group__API__Data__Management.html#ga07d895064336867923716b7c690c077d":[10,8,14],
"group__API__Data__Management.html#ga10d43386322955cba25889cf9b88b706":[10,8,48],
"group__API__Data__Management.html#ga1f5ba1c1cfefc1f81a4095cf3c213e54":[10,8,53],
"group__API__Data__Management.html#ga1fb3a1ff8622747d653d1b5f41bc41db":[10,8,5],
"group__API__Data__Management.html#ga23ad7e71f5e785d80c55cdf292c34ea8":[10,8,15],
"group__API__Data__Management.html#ga273df19e4cad1c05ec5df697bcec4444":[10,8,45],
"group__API__Data__Management.html#ga2ae876d62ebaf6e402c85991c912f21e":[10,8,55],
"group__API__Data__Management.html#ga2b9b64ac9a650d8c8942b4227e6fce75":[10,8,2],
"group__API__Data__Management.html#ga337cf01e2a0ccc1c3cc2ea27d5bdf131":[10,8,34],
"group__API__Data__Management.html#ga358aba7459b7f99a6dbaa189ce57b925":[10,8,21],
"group__API__Data__Management.html#ga3b2ca6406b5839062346200123551638":[10,8,20],
"group__API__Data__Management.html#ga4e82fe020ec010bcacb6aee16021607c":[10,8,16],
"group__API__Data__Management.html#ga4fa34753bff1d29c20f0a0e361020b4e":[10,8,13],
"group__API__Data__Management.html#ga5458fc0ffdc4b6bae960520f5f599ae5":[10,8,40],
"group__API__Data__Management.html#ga57687b811ced00dbfc35af73164a72aa":[10,8,37],
"group__API__Data__Management.html#ga586146498466b60d6b81145dfaeb8948":[10,8,11],
"group__API__Data__Management.html#ga5b95764e9545fc367cb995950e82f449":[10,8,29],
"group__API__Data__Management.html#ga5fd09305716ce9d3a5a9fd2df6bc7792":[10,8,60],
"group__API__Data__Management.html#ga690e27502b042cbc6969c5f3c5771a84":[10,8,25],
"group__API__Data__Management.html#ga6e0e15426e75b43f7b44e3f3a38c01f1":[10,8,51],
"group__API__Data__Management.html#ga70ee8a92cbb3935ec3ca0d40f443f860":[10,8,23],
"group__API__Data__Management.html#ga78ffeb2e27e87bfc118e7fe2157ae4c2":[10,8,27],
"group__API__Data__Management.html#ga7badde35fa2205201fad73fd851133fa":[10,8,30],
"group__API__Data__Management.html#ga80778d87c0e2181096124f03bebe53cd":[10,8,6],
"group__API__Data__Management.html#ga80b7284bb413ae7acac0fe83268c10f1":[10,8,50],
"group__API__Data__Management.html#ga8771ea54051655e68ed7a95b4b831fc7":[10,8,32],
"group__API__Data__Management.html#ga88a1a866445372adf0a07a349ecc7a5a":[10,8,10],
"group__API__Data__Management.html#ga8b98dee994de7c323a81ac6e573e5693":[10,8,49],
"group__API__Data__Management.html#ga8bcfd56807cf9436eca71c6e3ade2dab":[10,8,41],
"group__API__Data__Management.html#ga8db878885ebbee4729d8aed6a0479262":[10,8,22],
"group__API__Data__Management.html#ga916df5cfe739f832d51bd66012b500cb":[10,8,31],
"group__API__Data__Management.html#ga982a42a7afc942863de2349bc8f201a9":[10,8,26],
"group__API__Data__Management.html#ga9a6122bae224d714383ae775434cdce3":[10,8,52],
"group__API__Data__Management.html#ga9cbc51da2f2b7025c534d6862866bf81":[10,8,33],
"group__API__Data__Management.html#ga9ce32e79b2f07fb474b6ae10006abb1f":[10,8,36],
"group__API__Data__Management.html#ga9d4db8e3a8a6ea4c6757a455849e1504":[10,8,8],
"group__API__Data__Management.html#gaa1f95d17759711f7703bf02820e2e49b":[10,8,12],
"group__API__Data__Management.html#gaa62248a017ee1494ca399789d7687aac":[10,8,61],
"group__API__Data__Management.html#gaa9084f77b596022f0635b5e326bc450e":[10,8,7],
"group__API__Data__Management.html#gaaaaa769d715f01b5636a837fd86c9671":[10,8,59],
"group__API__Data__Management.html#gab3f057daac283b3b7351b03b0d574493":[10,8,43],
"group__API__Data__Management.html#gab9497db9ea78dafa7ba0a2b99a7fc0f2":[10,8,9],
"group__API__Data__Management.html#gab97817681d85c64d7d84e4b9a88c4811":[10,8,54],
"group__API__Data__Management.html#gabd61bf0201af91a3d4e6501ebdf8e851":[10,8,4],
"group__API__Data__Management.html#gac561fd637be17b74f0456106dc25f5d1":[10,8,35],
"group__API__Data__Management.html#gac83c13a23641632701971e2d48f7c5fa":[10,8,56],
"group__API__Data__Management.html#gac88c5f320d2c900923b7934d9a733104":[10,8,46],
"group__API__Data__Management.html#gaceb23371963b642f4155ffa728f3bf03":[10,8,1],
"group__API__Data__Management.html#gad5a24f94d0aa2bbfab8957c3dd13949a":[10,8,39],
"group__API__Data__Management.html#gad6bed33cdb76ef504efcdf05e5788076":[10,8,3],
"group__API__Data__Management.html#gadc145017bafa2948109c624715de77a2":[10,8,28],
"group__API__Data__Management.html#gae53e7b21c7426c9845a1046cfe5becce":[10,8,44],
"group__API__Data__Management.html#gae5f926615eaa6e318ee0fc4ac0be9e3e":[10,8,38],
"group__API__Data__Management.html#gae6eb535cf9bf46a7ef9ad2d845c675a2":[10,8,19],
"group__API__Data__Management.html#gaedc8031c1b437d35232cd1700d83d472":[10,8,18],
"group__API__Data__Management.html#gaef7203edaf1725977dffac23296ede4e":[10,8,47],
"group__API__Data__Management.html#gaf2811b5c7d3570edf483ca1ece4bf4a0":[10,8,62],
"group__API__Data__Management.html#gaf385e328d71dc2e202b17ec26f229414":[10,8,0],
"group__API__Data__Management.html#gaf971c53b3fa3d3746a8ae1f5291c7c4f":[10,8,57],
"group__API__Data__Management.html#gafd48044a523ed5a4e11598596096dc52":[10,8,24],
"group__API__Data__Management.html#gafd4b4f7f9f0a26f65a1e149525a09bfd":[10,8,42],
"group__API__Data__Management.html#gga1fb3a1ff8622747d653d1b5f41bc41dba408d8f229f4e9bc746c35725c4000f00":[10,8,5,12],
"group__API__Data__Management.html#gga1fb3a1ff8622747d653d1b5f41bc41dba4b095bb54466cef653c30284bc31b79e":[10,8,5,9],
"group__API__Data__Management.html#gga1fb3a1ff8622747d653d1b5f41bc41dba5531afb0a53e301d4bff753fed705179":[10,8,5,4],
"group__API__Data__Management.html#gga1fb3a1ff8622747d653d1b5f41bc41dba57727da3bb21784bb7949dfa334b4c6e":[10,8,5,13],
"group__API__Data__Management.html#gga1fb3a1ff8622747d653d1b5f41bc41dba5e9a6cc56e05350429ee4438ce47d504":[10,8,5,7],
"group__API__Data__Management.html#gga1fb3a1ff8622747d653d1b5f41bc41dba628e5483f4cb6e44779aea39300dafed":[10,8,5,2],
"group__API__Data__Management.html#gga1fb3a1ff8622747d653d1b5f41bc41dba9fb7d314ccc154aead02dab90f8db52b":[10,8,5,3],
"group__API__Data__Management.html#gga1fb3a1ff8622747d653d1b5f41bc41dbaa92c1e935fb451cc339a21976680ee05":[10,8,5,5],
"group__API__Data__Management.html#gga1fb3a1ff8622747d653d1b5f41bc41dbaab55b4cef9cfedeacae7012cd52e5389":[10,8,5,1],
"group__API__Data__Management.html#gga1fb3a1ff8622747d653d1b5f41bc41dbacc08b511187f8c1d9f81652f9c97a013":[10,8,5,11],
"group__API__Data__Management.html#gga1fb3a1ff8622747d653d1b5f41bc41dbade64878c777f3655d8802cbc6b48a95d":[10,8,5,6],
"group__API__Data__Management.html#gga1fb3a1ff8622747d653d1b5f41bc41dbae91fbbc42c9e5082cbd704016cf5fa96":[10,8,5,8],
"group__API__Data__Management.html#gga1fb3a1ff8622747d653d1b5f41bc41dbaecd4ea8fd4083c02cfe0f32742f37705":[10,8,5,10],
"group__API__Data__Management.html#gga1fb3a1ff8622747d653d1b5f41bc41dbafd6a1ff04c61fdecf309f45e01e91a16":[10,8,5,0],
"group__API__Data__Management.html#gga80778d87c0e2181096124f03bebe53cda2a3b541397e36d47ca5dc53eae3ae3bc":[10,8,6,1],
"group__API__Data__Management.html#gga80778d87c0e2181096124f03bebe53cda39bf29faf6696902c4b7dc49a172d0f4":[10,8,6,2],
"group__API__Data__Management.html#gga80778d87c0e2181096124f03bebe53cda7c3a0c090326084ae5598883fe4b5bdb":[10,8,6,3],
"group__API__Data__Management.html#gga80778d87c0e2181096124f03bebe53cdae5376738a045e337ad5519fb2b0c4ba5":[10,8,6,0],
"group__API__Data__Partition.html":[10,10],
"group__API__Data__Partition.html#a0794c07d3fbfab35b6889760699c7b91":[10,10,0,0],
"group__API__Data__Partition.html#a1ef5f824cca130aa51505b0551eca51c":[10,10,0,5],
"group__API__Data__Partition.html#a6cb433cf6efd383c6739099dccb3c2b0":[10,10,0,3],
"group__API__Data__Partition.html#a6cb631e64e61f862647040852fdabe49":[10,10,0,4],
"group__API__Data__Partition.html#aca2a185107bc8d8adc11557248cf454b":[10,10,0,2],
"group__API__Data__Partition.html#aec46586c98b5631201151b7582724e12":[10,10,0,1],
"group__API__Data__Partition.html#ga009a98e4a9780344e2f612732e820755":[10,10,43],
"group__API__Data__Partition.html#ga0e1bee4821237529d554605d333e9109":[10,10,24],
"group__API__Data__Partition.html#ga0f30a9d20dddf5c724f5253195dca268":[10,10,62],
"group__API__Data__Partition.html#ga117176bbe14cf26ae320fc5e1159216d":[10,10,91],
"group__API__Data__Partition.html#ga11ccadcd18ac19c6eb8710f90a561493":[10,10,9],
"group__API__Data__Partition.html#ga11e9d648c2cee65281f4d7b8d6d56a42":[10,10,58],
"group__API__Data__Partition.html#ga1363109ba0e36c1b6c7f1a40c9608791":[10,10,1],
"group__API__Data__Partition.html#ga14703620f86c508cf7ab773e86fd4f90":[10,10,79],
"group__API__Data__Partition.html#ga15a28291a5045ef7ed3c93afc94ed248":[10,10,8],
"group__API__Data__Partition.html#ga1897ebbc75bfec8ae1681bd8676635cd":[10,10,52],
"group__API__Data__Partition.html#ga1a265ffca51fae58701832a4daa53bd9":[10,10,44],
"group__API__Data__Partition.html#ga205e5302dbeca2f8bce15531a6720b09":[10,10,74],
"group__API__Data__Partition.html#ga212189d3b83dfa4e225609b5f2bf8461":[10,10,37],
"group__API__Data__Partition.html#ga2318b60efcf9eb250d548ddc9a33925d":[10,10,84],
"group__API__Data__Partition.html#ga2925be576ac7d597ecead381ff32a894":[10,10,31],
"group__API__Data__Partition.html#ga29e07c2c0604da63e7746a8018d8a62f":[10,10,3],
"group__API__Data__Partition.html#ga2b713d3a7a34dfd7416135d071aa3e48":[10,10,81],
"group__API__Data__Partition.html#ga305da4bdb4c0990aa53dbcc8f5dd4678":[10,10,76],
"group__API__Data__Partition.html#ga3233e3203e0541138cce8152c3ab9aa0":[10,10,56],
"group__API__Data__Partition.html#ga3b80f74f636512662d0d5a4a162ff537":[10,10,82],
"group__API__Data__Partition.html#ga3d4ca379476ef347e2001fa8dc177e6a":[10,10,87],
"group__API__Data__Partition.html#ga46d2b144a7de2e17d17b1383ef5f522d":[10,10,17],
"group__API__Data__Partition.html#ga47a12b7cc94a8bff0654761c36b8105d":[10,10,42],
"group__API__Data__Partition.html#ga4b910784c11bb46599fe9cb8928418f2":[10,10,27],
"group__API__Data__Partition.html#ga4f4c40532e5325daeea9b8912d17d293":[10,10,60],
"group__API__Data__Partition.html#ga4ff389a8d980d2a0c853ed1ec2018650":[10,10,65],
"group__API__Data__Partition.html#ga50821326fe102db514b57f4e92db5390":[10,10,93],
"group__API__Data__Partition.html#ga551d6fa7fead5b9f7c8a85b1f9885e91":[10,10,7],
"group__API__Data__Partition.html#ga554a2fb14fdee9353364c39f36ee3a6f":[10,10,28],
"group__API__Data__Partition.html#ga5fbd0dbede163e799d5ea916e7cff4ba":[10,10,78],
"group__API__Data__Partition.html#ga6103c299e4abb216aa8bf2513449acaa":[10,10,61],
"group__API__Data__Partition.html#ga68de40d4f32eaa18e20a070cf31648f5":[10,10,86],
"group__API__Data__Partition.html#ga695948a099ed2a340e73dd36074c65de":[10,10,68],
"group__API__Data__Partition.html#ga6a3f729055f14384e7397d2815a2c9a5":[10,10,4],
"group__API__Data__Partition.html#ga6c3d612b5161b5f72282b4bf9390525a":[10,10,39],
"group__API__Data__Partition.html#ga6dc5a62feeac787b7f6777e4d5c26162":[10,10,77],
"group__API__Data__Partition.html#ga7097f06b5541cec1ed607c1713e93892":[10,10,89],
"group__API__Data__Partition.html#ga7132923bd901e0e4254cc0b20d49997a":[10,10,32],
"group__API__Data__Partition.html#ga73a2c9af1200c68f0403e70e36c020d0":[10,10,46],
"group__API__Data__Partition.html#ga78df2076d8b7d46d0e7388dd94817188":[10,10,14],
"group__API__Data__Partition.html#ga78e1386083526cddd0741e3d63fbf925":[10,10,33],
"group__API__Data__Partition.html#ga7904efb86ab3f9d6d682a3a3be3646fe":[10,10,6],
"group__API__Data__Partition.html#ga7c2d2e40f20381ce2614852b22662bdb":[10,10,36],
"group__API__Data__Partition.html#ga7cc8832e25f2f4049ba5a0053b122dd9":[10,10,45],
"group__API__Data__Partition.html#ga7fcf158f5196d62610c5017993442c53":[10,10,13],
"group__API__Data__Partition.html#ga83e5a49ec30ec7a818e8f79bec8dc39d":[10,10,85],
"group__API__Data__Partition.html#ga88fbca61843b76314e39a2c0f8b93d6c":[10,10,30],
"group__API__Data__Partition.html#ga8a26c673507a7de484071e0926cb5638":[10,10,15],
"group__API__Data__Partition.html#ga8c86b2af9e0806e631c1cbb5d506506b":[10,10,29],
"group__API__Data__Partition.html#ga8c8b5f4aa20aa3aebc9180ee607026b0":[10,10,66],
"group__API__Data__Partition.html#ga8d9bfdd68b278fbb28b7a7208f72a76e":[10,10,57],
"group__API__Data__Partition.html#ga97abeb69473a5458b6b815289f44570e":[10,10,63],
"group__API__Data__Partition.html#ga994cbae9c619b070f8d219f6bfffff06":[10,10,12],
"group__API__Data__Partition.html#gaa204f1f0544ee8e14b050f9595b566a9":[10,10,88],
"group__API__Data__Partition.html#gaa2e7332ecabd177ac6808aef11bfa5fd":[10,10,10],
"group__API__Data__Partition.html#gaa4027885ab10cd89cbc3b1eb8b0a87ed":[10,10,70],
"group__API__Data__Partition.html#gaa4407a8734e1fbdbb63b83351769476c":[10,10,11],
"group__API__Data__Partition.html#gaa45ab07ead6106486f87ac10de029d5d":[10,10,83],
"group__API__Data__Partition.html#gaa91c8e107f03a35f4574395fde1c63a4":[10,10,25],
"group__API__Data__Partition.html#gaab49915dc0462c1b145bfb0a9ce4cf52":[10,10,38],
"group__API__Data__Partition.html#gaab4e795bb4d43972aaf5f37efdba3088":[10,10,34],
"group__API__Data__Partition.html#gaae4f93ab3326ded72c3a80d337e6f4a1":[10,10,48],
"group__API__Data__Partition.html#gab16748210b419286ba395c1ef7436ba8":[10,10,51],
"group__API__Data__Partition.html#gab639622ea4929c36df704a0bebfd3fac":[10,10,41],
"group__API__Data__Partition.html#gab915b6daaa4323e433688e7888e921d6":[10,10,22],
"group__API__Data__Partition.html#gab931b6026c134fa98bb72fb2f7c0c67f":[10,10,23],
"group__API__Data__Partition.html#gab9fa487bfff5ccdd59210bdde65a11db":[10,10,40],
"group__API__Data__Partition.html#gabd339fb3ebea0702e53f0dbe51b88810":[10,10,75],
"group__API__Data__Partition.html#gabf42e5f5ac41bd0db3afb9d314c52dbe":[10,10,80],
"group__API__Data__Partition.html#gabf9ff8712402c0da6f7a9d6c7e75c653":[10,10,54],
"group__API__Data__Partition.html#gac03a9cd945add8d2abea49f04741d437":[10,10,55],
"group__API__Data__Partition.html#gac0c6d0dbe85da2a9f0a57a43bb201a7b":[10,10,71],
"group__API__Data__Partition.html#gac146fc7646d16fb51a90ab087cfb7780":[10,10,72],
"group__API__Data__Partition.html#gac1e66049a48764a29d867a02bcc9d0ce":[10,10,18],
"group__API__Data__Partition.html#gac24101bbe28b1d7d4a0874d349ba8979":[10,10,5],
"group__API__Data__Partition.html#gac386115410b6817f0a8ae06eb528d549":[10,10,50],
"group__API__Data__Partition.html#gac4b9ec529f67e5c300e7eed3e185fbaf":[10,10,49],
"group__API__Data__Partition.html#gac4f0b5ce7cdee16c1311595e9ca53e98":[10,10,19],
"group__API__Data__Partition.html#gac7f9a90bf32df2cf3c71b85d3eb1b8d5":[10,10,67],
"group__API__Data__Partition.html#gac9783be12bb315477c871309b0cd4294":[10,10,26],
"group__API__Data__Partition.html#gac9e650e1e6eea0b1a1ffbe274917a12d":[10,10,59],
"group__API__Data__Partition.html#gae803c4cf3c9f8bb87cca1daab5d9f28e":[10,10,73],
"group__API__Data__Partition.html#gae80794b9cad7855a3ee54a4361f656ed":[10,10,2],
"group__API__Data__Partition.html#gaea478569a1a283c4cf7ef3920334b82e":[10,10,21],
"group__API__Data__Partition.html#gaebf905814dfca30acaf8af1676f36133":[10,10,64],
"group__API__Data__Partition.html#gaf06e835d29cba28fe63f2ebd3f344a39":[10,10,69],
"group__API__Data__Partition.html#gaf5ab84a38498558bf21cf940946ca4eb":[10,10,35],
"group__API__Data__Partition.html#gaf6c20fec19b8f6a52b2c392b865e084d":[10,10,16],
"group__API__Data__Partition.html#gaf7e4734553f7f621316fe1d25f016c49":[10,10,20],
"group__API__Data__Partition.html#gafa4818b571e98acd8696a1251b0d4e74":[10,10,47],
"group__API__Data__Partition.html#gafcd0f39820cfecdc0bdae98fd94f6bdc":[10,10,90],
"group__API__Data__Partition.html#gafdeeda580ed2a820d4210fdb5321a61a":[10,10,53],
"group__API__Data__Partition.html#gafe5dde35d5b88b83adbe9888329a4255":[10,10,92],
"group__API__Data__Partition.html#structstarpu__data__filter":[10,10,0],
"group__API__Expert__Mode.html":[10,33],
"group__API__Expert__Mode.html#ga4e8d1e607b2383f80b232c27ec6a9386":[10,33,1],
"group__API__Expert__Mode.html#ga5d52c35e46e387eed77dd9b7b39507a7":[10,33,2],
"group__API__Expert__Mode.html#gaf5f4a32a78630fb051a846cbdcd77d8b":[10,33,0],
"group__API__Explicit__Dependencies.html":[10,11],
"group__API__Explicit__Dependencies.html#ga19e120568fbd21fcac59b93ff324c45f":[10,11,4],
"group__API__Explicit__Dependencies.html#ga1a93d3d46ea5ade29a3a3ea76b6eb90d":[10,11,8],
"group__API__Explicit__Dependencies.html#ga2425f146494ef50105f99325f4120522":[10,11,18],
"group__API__Explicit__Dependencies.html#ga2ab771900cf19e039ade46594dbc5fce":[10,11,3],
"group__API__Explicit__Dependencies.html#ga53dc7bff09b441ee6a200cae99ca2cb8":[10,11,5],
"group__API__Explicit__Dependencies.html#ga6d09446c8849f42edeced84c558e6a49":[10,11,17],
"group__API__Explicit__Dependencies.html#ga863d71b775ec517493f81e731a64d134":[10,11,9],
"group__API__Explicit__Dependencies.html#gab0761a67174503b61aa8d0e0ee1c9212":[10,11,16],
"group__API__Explicit__Dependencies.html#gab5c86743355724ee2f9596de1ae221df":[10,11,10],
"group__API__Explicit__Dependencies.html#gabaef95d742d03c96453905602e511050":[10,11,7],
"group__API__Explicit__Dependencies.html#gabdb8d20fca507a93450fe775233dd20c":[10,11,15],
"group__API__Explicit__Dependencies.html#gac350ef8b876d63fb8885377f789853d2":[10,11,0],
"group__API__Explicit__Dependencies.html#gaccd7b337e14269be734af274fb11c1a4":[10,11,2],
"group__API__Explicit__Dependencies.html#gada6692ca393aa820bc105252ca19830f":[10,11,1],
"group__API__Explicit__Dependencies.html#gadbed48d64331463d4f9a9090933e5b9f":[10,11,14],
"group__API__Explicit__Dependencies.html#gae33176debf369b29f12e2e390f2d67e1":[10,11,6],
"group__API__Explicit__Dependencies.html#gaef0b7cee7536d4a5de1b10888ab13add":[10,11,13],
"group__API__Explicit__Dependencies.html#gaf5090c3c45414d693445e79ab7842992":[10,11,11],
"group__API__Explicit__Dependencies.html#gaf5cf68c72a863a6ab0ef8737c92b57ba":[10,11,12],
"group__API__FFT__Support.html":[10,1],
"group__API__FFT__Support.html#ga22ad2f1c869305d11132322039d38876":[10,1,6],
"group__API__FFT__Support.html#ga2b1a62489b5b48491067bc8dc39f4b16":[10,1,8],
"group__API__FFT__Support.html#ga4670f7ac8c6980f78b80b48bbe561299":[10,1,7]
};
